gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-anastasis-gtk] branch master updated: AG_ prefix rename fest


From: gnunet
Subject: [taler-anastasis-gtk] branch master updated: AG_ prefix rename fest
Date: Sun, 28 Mar 2021 21:16:47 +0200

This is an automated email from the git hooks/post-receive script.

grothoff pushed a commit to branch master
in repository anastasis-gtk.

The following commit(s) were added to refs/heads/master by this push:
     new 94a5635  AG_ prefix rename fest
94a5635 is described below

commit 94a56354e58e6ca6771459a6c168902c182ba2b3
Author: Christian Grothoff <christian@grothoff.org>
AuthorDate: Sun Mar 28 21:16:45 2021 +0200

    AG_ prefix rename fest
---
 contrib/anastasis_gtk_challenge_code.glade         |  50 ++++++-
 src/anastasis/anastasis-gtk.c                      |  27 ++--
 src/anastasis/anastasis-gtk.h                      |  10 +-
 src/anastasis/anastasis-gtk_action.c               | 152 ++++++++++++---------
 src/anastasis/anastasis-gtk_attributes.c           |   2 +-
 src/anastasis/anastasis-gtk_backup.c               |   2 +-
 src/anastasis/anastasis-gtk_dispatch.c             |   2 +-
 src/anastasis/anastasis-gtk_dispatch.h             |   2 +-
 ...astasis-gtk_handle-auth-delete-button-clicked.c |  10 +-
 ...astasis-gtk_handle-auth-edit-provider-clicked.c |  14 +-
 .../anastasis-gtk_handle-backup-button-clicked.c   |   2 +-
 .../anastasis-gtk_handle-challenge-code.c          |  21 +--
 .../anastasis-gtk_handle-challenge-question.c      |  22 +--
 .../anastasis-gtk_handle-continent-activated.c     |  10 +-
 .../anastasis-gtk_handle-continent-unselected.c    |  10 +-
 .../anastasis-gtk_handle-identity-changed.c        |   2 +-
 ...anastasis-gtk_handle-main-window-back-clicked.c |  16 +--
 ...stasis-gtk_handle-main-window-forward-clicked.c |  50 +++----
 src/anastasis/anastasis-gtk_handle-method-email.c  |  10 +-
 src/anastasis/anastasis-gtk_handle-method-post.c   |  10 +-
 .../anastasis-gtk_handle-method-question.c         |  10 +-
 src/anastasis/anastasis-gtk_handle-method-sms.c    |  10 +-
 src/anastasis/anastasis-gtk_handle-method-video.c  |   2 +-
 .../anastasis-gtk_handle-policy-version-changed.c  |  18 +--
 .../anastasis-gtk_handle-recovery-button-clicked.c |   2 +-
 .../anastasis-gtk_handle-secret-buttons.c          |  14 +-
 src/anastasis/anastasis-gtk_helper.c               |   8 +-
 src/anastasis/anastasis-gtk_io.c                   |   6 +-
 28 files changed, 278 insertions(+), 216 deletions(-)

diff --git a/contrib/anastasis_gtk_challenge_code.glade 
b/contrib/anastasis_gtk_challenge_code.glade
index b95b70c..a2ec6b3 100644
--- a/contrib/anastasis_gtk_challenge_code.glade
+++ b/contrib/anastasis_gtk_challenge_code.glade
@@ -65,6 +65,45 @@
             <property name="position">0</property>
           </packing>
         </child>
+        <child>
+          <object class="GtkBox" id="anastasis_gtk_c_challenge_box">
+            <property name="visible">True</property>
+            <property name="can-focus">False</property>
+            <child>
+              <object class="GtkLabel" 
id="anastasis_gtk_c_challenge_pre_label">
+                <property name="visible">True</property>
+                <property name="can-focus">False</property>
+                <property name="label" translatable="yes">Challenge:</property>
+              </object>
+              <packing>
+                <property name="expand">False</property>
+                <property name="fill">False</property>
+                <property name="padding">5</property>
+                <property name="position">0</property>
+              </packing>
+            </child>
+            <child>
+              <object class="GtkLabel" id="anastasis_gtk_c_challenge_label">
+                <property name="visible">True</property>
+                <property name="can-focus">False</property>
+                <property name="label">SET DYNAMICALLY BY PROGRAM</property>
+                <attributes>
+                  <attribute name="style" value="italic"/>
+                </attributes>
+              </object>
+              <packing>
+                <property name="expand">False</property>
+                <property name="fill">True</property>
+                <property name="position">1</property>
+              </packing>
+            </child>
+          </object>
+          <packing>
+            <property name="expand">False</property>
+            <property name="fill">True</property>
+            <property name="position">1</property>
+          </packing>
+        </child>
         <child>
           <object class="GtkBox">
             <property name="visible">True</property>
@@ -89,7 +128,7 @@
                   <object class="GtkLabel">
                     <property name="visible">True</property>
                     <property name="can-focus">False</property>
-                    <property name="label" translatable="yes">A challenge code 
has been send to:</property>
+                    <property name="label" translatable="yes">Code sent 
to:</property>
                   </object>
                   <packing>
                     <property name="expand">False</property>
@@ -136,7 +175,7 @@
           <packing>
             <property name="expand">False</property>
             <property name="fill">True</property>
-            <property name="position">1</property>
+            <property name="position">2</property>
           </packing>
         </child>
         <child>
@@ -147,7 +186,7 @@
               <object class="GtkLabel">
                 <property name="visible">True</property>
                 <property name="can-focus">False</property>
-                <property name="label" translatable="yes">Enter 
code:</property>
+                <property name="label" translatable="yes">Enter the 
code:</property>
               </object>
               <packing>
                 <property name="expand">False</property>
@@ -161,8 +200,9 @@
                 <property name="visible">True</property>
                 <property name="can-focus">True</property>
                 <property name="hexpand">True</property>
-                <property name="width-chars">60</property>
+                <property name="width-chars">24</property>
                 <property 
name="primary-icon-stock">gtk-dialog-authentication</property>
+                <property name="placeholder-text" 
translatable="yes">A-</property>
                 <signal name="changed" 
handler="anastasis_gtk_c_code_dialog_answer_entry_changed_cb" swapped="no"/>
               </object>
               <packing>
@@ -187,7 +227,7 @@
       <action-widget 
response="-5">anastasis_gtk_c_code_dialog_btn_ok</action-widget>
     </action-widgets>
     <child type="titlebar">
-      <object class="GtkLabel">
+      <object class="GtkLabel" id="anastasis_gtk_c_code_dialog_label">
         <property name="visible">True</property>
         <property name="can-focus">False</property>
         <property name="label" translatable="yes">Security token 
challenge</property>
diff --git a/src/anastasis/anastasis-gtk.c b/src/anastasis/anastasis-gtk.c
index 7b91ac9..61ce06d 100644
--- a/src/anastasis/anastasis-gtk.c
+++ b/src/anastasis/anastasis-gtk.c
@@ -33,12 +33,12 @@
 /**
  * Handle to our main loop.
  */
-struct GNUNET_GTK_MainLoop *ml;
+struct GNUNET_GTK_MainLoop *AG_ml;
 
 /**
  * Our configuration.
  */
-const struct GNUNET_CONFIGURATION_Handle *cfg;
+const struct GNUNET_CONFIGURATION_Handle *AG_cfg;
 
 /**
  * Closure for #GNUNET_CURL_gnunet_scheduler_reschedule().
@@ -58,12 +58,12 @@ static struct GNUNET_CURL_Context *ctx;
 /**
  * Handle to an ongoing action.
  */
-struct ANASTASIS_ReduxAction *ra;
+struct ANASTASIS_ReduxAction *AG_ra;
 
 /**
  * Actual state.
  */
-json_t *redux_state;
+json_t *AG_AG_redux_state;
 
 
 /**
@@ -147,10 +147,10 @@ shutdown_task (void *cls)
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Shutdown initiated\n");
   ANASTASIS_redux_done ();
-  if (NULL != ra)
+  if (NULL != AG_ra)
   {
-    ANASTASIS_redux_action_cancel (ra);
-    ra = NULL;
+    ANASTASIS_redux_action_cancel (AG_ra);
+    AG_ra = NULL;
   }
   if (NULL != ctx)
   {
@@ -162,8 +162,8 @@ shutdown_task (void *cls)
     GNUNET_CURL_gnunet_rc_destroy (rc);
     rc = NULL;
   }
-  GNUNET_GTK_main_loop_quit (ml);
-  ml = NULL;
+  GNUNET_GTK_main_loop_quit (AG_ml);
+  AG_ml = NULL;
   GNUNET_CONTAINER_multihashmap_destroy (AG_entry_attributes);
   AG_entry_attributes = NULL;
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
@@ -237,18 +237,17 @@ run (void *cls)
   int argc;
   char *const *argv;
 
-  ml = cls;
+  AG_ml = cls;
   AG_entry_attributes = GNUNET_CONTAINER_multihashmap_create (16,
                                                               GNUNET_NO);
   if (GNUNET_OK !=
-      GNUNET_GTK_main_loop_build_window (ml,
+      GNUNET_GTK_main_loop_build_window (AG_ml,
                                          NULL))
     return;
-  cfg = GNUNET_GTK_main_loop_get_configuration (ml);
+  AG_cfg = GNUNET_GTK_main_loop_get_configuration (AG_ml);
   GNUNET_GTK_set_icon_search_path ();
   GNUNET_GTK_setup_nls ();
-
-  GNUNET_GTK_main_loop_get_args (ml,
+  GNUNET_GTK_main_loop_get_args (AG_ml,
                                  &argc,
                                  &argv);
   /* setup main window */
diff --git a/src/anastasis/anastasis-gtk_action.c 
b/src/anastasis/anastasis-gtk_action.c
index 55bd379..a70ef36 100644
--- a/src/anastasis/anastasis-gtk_action.c
+++ b/src/anastasis/anastasis-gtk_action.c
@@ -58,7 +58,7 @@ action_continent_selecting (void)
       = GTK_LIST_STORE (
           GCG_get_main_window_object ("continent_liststore"));
     gtk_list_store_clear (continent_liststore);
-    continents = json_object_get (redux_state,
+    continents = json_object_get (AG_AG_redux_state,
                                   "continents");
     if (NULL != continents)
     {
@@ -100,10 +100,10 @@ action_country_selecting (void)
   const char *selected_country;
 
   AG_hide_all_frames ();
-  countries = json_object_get (redux_state,
+  countries = json_object_get (AG_AG_redux_state,
                                "countries");
   selected_country
-    = json_string_value (json_object_get (redux_state,
+    = json_string_value (json_object_get (AG_AG_redux_state,
                                           "selected_country"));
   country_liststore = GTK_LIST_STORE (
     GCG_get_main_window_object ("country_liststore"));
@@ -339,7 +339,7 @@ action_user_attributes_collecting (void)
   const json_t *id_attributes;
 
   AG_hide_all_frames ();
-  id_attributes = json_object_get (redux_state,
+  id_attributes = json_object_get (AG_AG_redux_state,
                                    "required_attributes");
   GNUNET_assert (NULL != id_attributes);
   AG_hide_children ("anastasis_gtk_identity_vbox");
@@ -462,7 +462,7 @@ action_user_attributes_collecting (void)
         json_t *ia;
         json_t *val;
 
-        ia = json_object_get (redux_state,
+        ia = json_object_get (AG_AG_redux_state,
                               "identity_attributes");
         val = json_object_get (ia,
                                attr_name);
@@ -532,7 +532,7 @@ action_authentications_editing (void)
 
   AG_hide_all_frames ();
   AG_insensitive_children ("anastasis_gtk_add_auth_button_box");
-  aps = json_object_get (redux_state,
+  aps = json_object_get (AG_AG_redux_state,
                          "authentication_providers");
   {
     const json_t *ap;
@@ -599,7 +599,7 @@ action_authentications_editing (void)
     ls = GTK_LIST_STORE (GCG_get_main_window_object (
                            "authentication_methods_liststore"));
     gtk_list_store_clear (ls);
-    ams = json_object_get (redux_state,
+    ams = json_object_get (AG_AG_redux_state,
                            "authentication_methods");
     json_array_foreach (ams,
                         index,
@@ -646,7 +646,7 @@ action_authentications_editing (void)
 
 /**
  * Lookup @a method_cost of authentication method @a type at @a provider in our
- * #redux_state.
+ * #AG_AG_redux_state.
  *
  * @param provider URL of provider
  * @param type authentication method to look for
@@ -666,7 +666,7 @@ lookup_recovery_cost (const char *provider,
   memset (method_cost,
           0,
           sizeof (struct TALER_Amount));
-  aps = json_object_get (redux_state,
+  aps = json_object_get (AG_AG_redux_state,
                          "authentication_providers");
   GNUNET_assert (NULL != aps);
   ap = json_object_get (aps,
@@ -720,7 +720,7 @@ action_policies_reviewing (void)
   AG_hide_all_frames ();
   ts = GTK_TREE_STORE (GCG_get_main_window_object ("policy_review_treestore"));
   gtk_tree_store_clear (ts);
-  policies = json_object_get (redux_state,
+  policies = json_object_get (AG_AG_redux_state,
                               "policies");
   GNUNET_assert (NULL != policies);
   json_array_foreach (policies, pindex, policy)
@@ -781,7 +781,7 @@ action_policies_reviewing (void)
         GNUNET_break (0);
         continue;
       }
-      jmethods = json_object_get (redux_state,
+      jmethods = json_object_get (AG_AG_redux_state,
                                   "authentication_methods");
       jmethod = json_array_get (jmethods,
                                 imethod);
@@ -875,7 +875,7 @@ action_secret_editing (void)
   entry = GTK_ENTRY (GCG_get_main_window_object (
                        "anastasis_gtk_enter_secret_entry"));
   if ( (GNUNET_OK ==
-        GNUNET_JSON_parse (redux_state,
+        GNUNET_JSON_parse (AG_AG_redux_state,
                            spec,
                            NULL, NULL)) &&
        (0 < strlen (secret)) )
@@ -1047,7 +1047,7 @@ action_truths_paying (void)
   ls = GTK_LIST_STORE (GCG_get_main_window_object (
                          "unpaid_qrcodes_liststore"));
   gtk_list_store_clear (ls);
-  pprs = json_object_get (redux_state,
+  pprs = json_object_get (AG_AG_redux_state,
                           "payments");
   json_array_foreach (pprs, index, pt)
   {
@@ -1085,15 +1085,15 @@ action_truths_paying (void)
     struct GNUNET_TIME_Relative timeout;
 
     timeout = GNUNET_TIME_UNIT_MINUTES;
-    GNUNET_assert (NULL == ra);
+    GNUNET_assert (NULL == AG_ra);
     args = json_pack ("{s:o}",
                       "timeout",
                       GNUNET_JSON_from_time_rel (timeout));
-    ra = ANASTASIS_redux_action (redux_state,
-                                 "pay",
-                                 args,
-                                 &AG_action_cb,
-                                 NULL);
+    AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                    "pay",
+                                    args,
+                                    &AG_action_cb,
+                                    NULL);
     json_decref (args);
   }
   AG_show ("anastasis_gtk_pay_frame");
@@ -1116,7 +1116,7 @@ action_policies_paying (void)
   ls = GTK_LIST_STORE (GCG_get_main_window_object (
                          "unpaid_qrcodes_liststore"));
   gtk_list_store_clear (ls);
-  pprs = json_object_get (redux_state,
+  pprs = json_object_get (AG_AG_redux_state,
                           "policy_payment_requests");
   json_array_foreach (pprs, index, ppr)
   {
@@ -1164,15 +1164,15 @@ action_policies_paying (void)
     struct GNUNET_TIME_Relative timeout;
 
     timeout = GNUNET_TIME_UNIT_MINUTES;
-    GNUNET_assert (NULL == ra);
+    GNUNET_assert (NULL == AG_ra);
     args = json_pack ("{s:o}",
                       "timeout",
                       GNUNET_JSON_from_time_rel (timeout));
-    ra = ANASTASIS_redux_action (redux_state,
-                                 "pay",
-                                 args,
-                                 &AG_action_cb,
-                                 NULL);
+    AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                    "pay",
+                                    args,
+                                    &AG_action_cb,
+                                    NULL);
     json_decref (args);
   }
   AG_show ("anastasis_gtk_pay_frame");
@@ -1192,7 +1192,7 @@ action_backup_finished (void)
   GtkListStore *ls;
 
   AG_hide_all_frames ();
-  arr = json_object_get (redux_state,
+  arr = json_object_get (AG_AG_redux_state,
                          "success_details");
   ls = GTK_LIST_STORE (GCG_get_main_window_object (
                          "backup_provider_liststore"));
@@ -1259,11 +1259,11 @@ challenge_button_clicked_cb (GtkButton *button,
   GNUNET_assert (NULL != uuid);
   GNUNET_assert (NULL != args);
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
-                               "select_challenge",
-                               args,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "select_challenge",
+                                  args,
+                                  &AG_action_cb,
+                                  NULL);
   json_decref (args);
 }
 
@@ -1293,7 +1293,7 @@ find_challenge_by_uuid (const char *uuid)
   size_t index;
   json_t *c;
 
-  rd = json_object_get (redux_state,
+  rd = json_object_get (AG_AG_redux_state,
                         "recovery_document");
   cs = json_object_get (rd,
                         "cs");
@@ -1337,7 +1337,7 @@ action_challenge_selecting (void)
     bt = GTK_COMBO_BOX_TEXT (GCG_get_main_window_object (
                                "anastasis_gtk_provider_url_combo_box_text"));
     gtk_combo_box_text_remove_all (bt);
-    aps = json_object_get (redux_state,
+    aps = json_object_get (AG_AG_redux_state,
                            "authentication_providers");
     json_object_foreach (aps,
                          provider_url,
@@ -1348,7 +1348,7 @@ action_challenge_selecting (void)
                                       provider_url);
     }
   }
-  re = json_object_get (redux_state,
+  re = json_object_get (AG_AG_redux_state,
                         "recovery_error");
   if (NULL != re)
   {
@@ -1400,7 +1400,7 @@ action_challenge_selecting (void)
     }
     return;
   }
-  ri = json_object_get (redux_state,
+  ri = json_object_get (AG_AG_redux_state,
                         "recovery_information");
   {
     uint64_t version;
@@ -1433,7 +1433,7 @@ action_challenge_selecting (void)
     gtk_entry_set_text (ge,
                         provider_url);
   }
-  rd = json_object_get (redux_state,
+  rd = json_object_get (AG_AG_redux_state,
                         "recovery_document");
   {
     GtkTreeStore *ts;
@@ -1668,7 +1668,7 @@ action_challenge_paying (void)
   ls = GTK_LIST_STORE (GCG_get_main_window_object (
                          "unpaid_qrcodes_liststore"));
   gtk_list_store_clear (ls);
-  pprs = json_object_get (redux_state,
+  pprs = json_object_get (AG_AG_redux_state,
                           "challenge_feedback");
   json_object_foreach (pprs, uuid, ppr)
   {
@@ -1732,17 +1732,17 @@ action_challenge_paying (void)
     struct GNUNET_TIME_Relative timeout;
 
     timeout = GNUNET_TIME_UNIT_MINUTES;
-    GNUNET_assert (NULL == ra);
+    GNUNET_assert (NULL == AG_ra);
     args = json_pack ("{s:o, s:s}",
                       "timeout",
                       GNUNET_JSON_from_time_rel (timeout),
                       "payment_secret",
                       ps);
-    ra = ANASTASIS_redux_action (redux_state,
-                                 "pay",
-                                 args,
-                                 &AG_action_cb,
-                                 NULL);
+    AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                    "pay",
+                                    args,
+                                    &AG_action_cb,
+                                    NULL);
     json_decref (args);
   }
   else
@@ -1796,9 +1796,6 @@ static GtkDialog *
 diag_code (const json_t *details)
 {
   GtkBuilder *builder;
-  GtkDialog *ad;
-  GtkLabel *label;
-  const char *instructions;
 
   builder = GNUNET_GTK_get_new_builder ("anastasis_gtk_challenge_code.glade",
                                         NULL);
@@ -1807,15 +1804,38 @@ diag_code (const json_t *details)
     GNUNET_break (0);
     return NULL;
   }
-  ad = GTK_DIALOG (gtk_builder_get_object (builder,
-                                           "anastasis_gtk_c_code_dialog"));
-  label = GTK_LABEL (gtk_builder_get_object (builder,
-                                             "challenge_instructions_label"));
-  instructions = json_string_value (json_object_get (details,
-                                                     "instructions"));
-  gtk_label_set_text (label,
-                      instructions);
-  return ad;
+  {
+    GtkLabel *label;
+    const char *instructions;
+
+    label = GTK_LABEL (gtk_builder_get_object (builder,
+                                               
"challenge_instructions_label"));
+    instructions = json_string_value (json_object_get (details,
+                                                       "instructions"));
+    gtk_label_set_text (label,
+                        instructions);
+  }
+  {
+    GtkLabel *clabel;
+    const char *uuid_str;
+
+    clabel = GTK_LABEL (gtk_builder_get_object (builder,
+                                                
"anastasis_gtk_c_challenge_label"));
+    uuid_str = json_string_value (json_object_get (details,
+                                                   "uuid"));
+    gtk_label_set_text (clabel,
+                        uuid_str);
+    json_dumpf (details,
+                stderr,
+                JSON_INDENT (2));
+  }
+  {
+    GtkDialog *ad;
+
+    ad = GTK_DIALOG (gtk_builder_get_object (builder,
+                                             "anastasis_gtk_c_code_dialog"));
+    return ad;
+  }
 }
 
 
@@ -1843,7 +1863,7 @@ action_challenge_solving (void)
   const char *uuid;
   const json_t *challenge;
 
-  uuid = json_string_value (json_object_get (redux_state,
+  uuid = json_string_value (json_object_get (AG_AG_redux_state,
                                              "selected_challenge_uuid"));
   if (NULL == uuid)
   {
@@ -1915,7 +1935,7 @@ action_recovery_finished (void)
   l = GTK_LABEL (GCG_get_main_window_object (
                    "anastasis_gtk_secret_value_label"));
   GNUNET_assert (GNUNET_OK ==
-                 GNUNET_JSON_parse (redux_state,
+                 GNUNET_JSON_parse (AG_AG_redux_state,
                                     spec,
                                     NULL, NULL));
   gtk_label_set_text (l,
@@ -1986,7 +2006,7 @@ AG_action_cb (void *cls,
   };
 
   (void) cls;
-  ra = NULL;
+  AG_ra = NULL;
   AG_thaw ();
 #if DEBUG
   fprintf (stderr,
@@ -2012,8 +2032,8 @@ AG_action_cb (void *cls,
   }
   else
   {
-    json_decref (redux_state);
-    redux_state = json_incref (response);
+    json_decref (AG_AG_redux_state);
+    AG_AG_redux_state = json_incref (response);
   }
   in_action = true;
   if (GNUNET_OK ==
@@ -2024,15 +2044,15 @@ AG_action_cb (void *cls,
   }
   in_action = false;
   AG_error ("Unhandled state `%s/%s'",
-            json_string_value (json_object_get (redux_state,
+            json_string_value (json_object_get (AG_AG_redux_state,
                                                 "backup_state")),
-            json_string_value (json_object_get (redux_state,
+            json_string_value (json_object_get (AG_AG_redux_state,
                                                 "recovery_state")));
-  json_dumpf (redux_state,
+  json_dumpf (AG_AG_redux_state,
               stderr,
               JSON_INDENT (2));
-  json_decref (redux_state);
-  redux_state = NULL;
+  json_decref (AG_AG_redux_state);
+  AG_AG_redux_state = NULL;
   AG_hide_all_frames ();
   AG_show ("anastasis_gtk_start_frame");
 }
diff --git a/src/anastasis/anastasis-gtk_attributes.c 
b/src/anastasis/anastasis-gtk_attributes.c
index ad8b113..c41a923 100644
--- a/src/anastasis/anastasis-gtk_attributes.c
+++ b/src/anastasis/anastasis-gtk_attributes.c
@@ -87,7 +87,7 @@ AG_collect_attributes (bool partial)
   size_t index;
   json_t *id_attr;
 
-  id_attributes = json_object_get (redux_state,
+  id_attributes = json_object_get (AG_AG_redux_state,
                                    "required_attributes");
   GNUNET_assert (NULL != id_attributes);
   result = json_object ();
diff --git a/src/anastasis/anastasis-gtk_backup.c 
b/src/anastasis/anastasis-gtk_backup.c
index 7799ce4..b1f2949 100644
--- a/src/anastasis/anastasis-gtk_backup.c
+++ b/src/anastasis/anastasis-gtk_backup.c
@@ -71,7 +71,7 @@ anastasis_gtk_b_video_dialog_btn_ok_clicked_cb (GObject 
*object,
     json_object_set_new (auth_method, "data", method_data);
     json_object_set_new (arguments, "authentication_method", method_data);
 
-    ra = ANASTASIS_redux_action (redux_state,
+    ra = ANASTASIS_redux_action (AG_AG_redux_state,
                                  "add_authentication",
                                  arguments,
                                  &AG_action_cb,
diff --git a/src/anastasis/anastasis-gtk_dispatch.c 
b/src/anastasis/anastasis-gtk_dispatch.c
index 2293e8f..a5975e2 100644
--- a/src/anastasis/anastasis-gtk_dispatch.c
+++ b/src/anastasis/anastasis-gtk_dispatch.c
@@ -32,7 +32,7 @@ AG_dispatch (const struct DispatchItem *dt)
 {
   for (unsigned int i = 0; NULL != dt[i].state; i++)
   {
-    if (! AG_check_state (redux_state,
+    if (! AG_check_state (AG_AG_redux_state,
                           dt[i].state))
       continue;
     dt[i].action ();
diff --git a/src/anastasis/anastasis-gtk_dispatch.h 
b/src/anastasis/anastasis-gtk_dispatch.h
index 13c47ba..effa1f2 100644
--- a/src/anastasis/anastasis-gtk_dispatch.h
+++ b/src/anastasis/anastasis-gtk_dispatch.h
@@ -45,7 +45,7 @@ struct DispatchItem
 
 /**
  * Run actions as per the given dispatch table based on the
- * current #redux_state.
+ * current #AG_AG_redux_state.
  *
  * @param dt dispatching table
  * @return #GNUNET_OK if an action was run from @a dt
diff --git a/src/anastasis/anastasis-gtk_handle-auth-delete-button-clicked.c 
b/src/anastasis/anastasis-gtk_handle-auth-delete-button-clicked.c
index b8da026..a10cd49 100644
--- a/src/anastasis/anastasis-gtk_handle-auth-delete-button-clicked.c
+++ b/src/anastasis/anastasis-gtk_handle-auth-delete-button-clicked.c
@@ -63,11 +63,11 @@ 
anastasis_gtk_authentication_method_delete_button_clicked_cb (GObject *object,
   args = json_pack ("{s:I}",
                     "auth_method_index",
                     index);
-  ra = ANASTASIS_redux_action (redux_state,
-                               "delete_authentication",
-                               args,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "delete_authentication",
+                                  args,
+                                  &AG_action_cb,
+                                  NULL);
   json_decref (args);
 }
 
diff --git a/src/anastasis/anastasis-gtk_handle-auth-edit-provider-clicked.c 
b/src/anastasis/anastasis-gtk_handle-auth-edit-provider-clicked.c
index adbcd67..80d2356 100644
--- a/src/anastasis/anastasis-gtk_handle-auth-edit-provider-clicked.c
+++ b/src/anastasis/anastasis-gtk_handle-auth-edit-provider-clicked.c
@@ -109,7 +109,7 @@ edit_provider_dialog_response_cb (GtkDialog *dialog,
     GNUNET_break (0);
     return;
   }
-  providers = json_object_get (redux_state,
+  providers = json_object_get (AG_AG_redux_state,
                                "authentication_providers");
   urls = json_array ();
   if (gtk_tree_model_get_iter_first (tm,
@@ -141,11 +141,11 @@ edit_provider_dialog_response_cb (GtkDialog *dialog,
                       "urls",
                       urls);
     AG_freeze ();
-    ra = ANASTASIS_redux_action (redux_state,
-                                 "add_provider",
-                                 args,
-                                 &AG_action_cb,
-                                 NULL);
+    AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                    "add_provider",
+                                    args,
+                                    &AG_action_cb,
+                                    NULL);
     json_decref (args);
   }
 }
@@ -175,7 +175,7 @@ anastasis_gtk_edit_provider_list_clicked_cb (GtkButton 
*object,
   }
   ls = GTK_LIST_STORE (gtk_builder_get_object (builder,
                                                "provider_liststore"));
-  providers = json_object_get (redux_state,
+  providers = json_object_get (AG_AG_redux_state,
                                "authentication_providers");
   {
     const char *url;
diff --git a/src/anastasis/anastasis-gtk_handle-backup-button-clicked.c 
b/src/anastasis/anastasis-gtk_handle-backup-button-clicked.c
index 9f06c81..ac58cfb 100644
--- a/src/anastasis/anastasis-gtk_handle-backup-button-clicked.c
+++ b/src/anastasis/anastasis-gtk_handle-backup-button-clicked.c
@@ -44,7 +44,7 @@ anastasis_gtk_backup_button_clicked (GObject *object,
   json_t *j;
 
   AG_freeze ();
-  j = ANASTASIS_backup_start (cfg);
+  j = ANASTASIS_backup_start (AG_cfg);
   AG_action_cb (NULL,
                 TALER_EC_NONE,
                 j);
diff --git a/src/anastasis/anastasis-gtk_handle-challenge-code.c 
b/src/anastasis/anastasis-gtk_handle-challenge-code.c
index 1a66dc8..11e46e8 100644
--- a/src/anastasis/anastasis-gtk_handle-challenge-code.c
+++ b/src/anastasis/anastasis-gtk_handle-challenge-code.c
@@ -54,11 +54,12 @@ anastasis_gtk_c_code_dialog_response_cb (GtkDialog *dialog,
   {
     gtk_widget_destroy (GTK_WIDGET (dialog));
     g_object_unref (G_OBJECT (builder));
-    ra = ANASTASIS_redux_action (redux_state,
-                                 "back",
-                                 NULL,
-                                 &AG_action_cb,
-                                 NULL);
+    GNUNET_assert (NULL == AG_ra);
+    AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                    "back",
+                                    NULL,
+                                    &AG_action_cb,
+                                    NULL);
     return;
   }
   q = GTK_ENTRY (gtk_builder_get_object (builder,
@@ -78,11 +79,11 @@ anastasis_gtk_c_code_dialog_response_cb (GtkDialog *dialog,
   gtk_widget_destroy (GTK_WIDGET (dialog));
   g_object_unref (G_OBJECT (builder));
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
-                               "solve_challenge",
-                               args,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "solve_challenge",
+                                  args,
+                                  &AG_action_cb,
+                                  NULL);
   json_decref (args);
 }
 
diff --git a/src/anastasis/anastasis-gtk_handle-challenge-question.c 
b/src/anastasis/anastasis-gtk_handle-challenge-question.c
index e50cb4c..8ed3c39 100644
--- a/src/anastasis/anastasis-gtk_handle-challenge-question.c
+++ b/src/anastasis/anastasis-gtk_handle-challenge-question.c
@@ -52,11 +52,12 @@ anastasis_gtk_c_question_dialog_response_cb (GtkDialog 
*dialog,
   {
     gtk_widget_destroy (GTK_WIDGET (dialog));
     g_object_unref (G_OBJECT (builder));
-    ra = ANASTASIS_redux_action (redux_state,
-                                 "back",
-                                 NULL,
-                                 &AG_action_cb,
-                                 NULL);
+    GNUNET_assert (NULL == AG_ra);
+    AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                    "back",
+                                    NULL,
+                                    &AG_action_cb,
+                                    NULL);
     return;
   }
   q = GTK_ENTRY (gtk_builder_get_object (builder,
@@ -68,11 +69,12 @@ anastasis_gtk_c_question_dialog_response_cb (GtkDialog 
*dialog,
   gtk_widget_destroy (GTK_WIDGET (dialog));
   g_object_unref (G_OBJECT (builder));
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
-                               "solve_challenge",
-                               args,
-                               &AG_action_cb,
-                               NULL);
+  GNUNET_assert (NULL == AG_ra);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "solve_challenge",
+                                  args,
+                                  &AG_action_cb,
+                                  NULL);
   json_decref (args);
 }
 
diff --git a/src/anastasis/anastasis-gtk_handle-continent-activated.c 
b/src/anastasis/anastasis-gtk_handle-continent-activated.c
index 5637380..43df116 100644
--- a/src/anastasis/anastasis-gtk_handle-continent-activated.c
+++ b/src/anastasis/anastasis-gtk_handle-continent-activated.c
@@ -66,10 +66,10 @@ anastasis_gtk_continent_activated (GtkTreeView *tree_view,
   GNUNET_assert (NULL != arguments);
   g_free (continent_name);
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
-                               "select_continent",
-                               arguments,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "select_continent",
+                                  arguments,
+                                  &AG_action_cb,
+                                  NULL);
   json_decref (arguments);
 }
diff --git a/src/anastasis/anastasis-gtk_handle-continent-unselected.c 
b/src/anastasis/anastasis-gtk_handle-continent-unselected.c
index f0b7803..9e4665b 100644
--- a/src/anastasis/anastasis-gtk_handle-continent-unselected.c
+++ b/src/anastasis/anastasis-gtk_handle-continent-unselected.c
@@ -47,9 +47,9 @@ anastasis_gtk_continent_unselected (GtkTreeSelection 
*selection,
                                        NULL))
     return;
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
-                               "unselect_continent",
-                               NULL,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "unselect_continent",
+                                  NULL,
+                                  &AG_action_cb,
+                                  NULL);
 }
diff --git a/src/anastasis/anastasis-gtk_handle-identity-changed.c 
b/src/anastasis/anastasis-gtk_handle-identity-changed.c
index cd00fe0..4fcbf56 100644
--- a/src/anastasis/anastasis-gtk_handle-identity-changed.c
+++ b/src/anastasis/anastasis-gtk_handle-identity-changed.c
@@ -67,7 +67,7 @@ check_attributes_fullfilled (void)
   if (NULL == args)
     return false;
   result = false;
-  ta = ANASTASIS_redux_action (redux_state,
+  ta = ANASTASIS_redux_action (AG_AG_redux_state,
                                "enter_user_attributes",
                                args,
                                &test_ok_cb,
diff --git a/src/anastasis/anastasis-gtk_handle-main-window-back-clicked.c 
b/src/anastasis/anastasis-gtk_handle-main-window-back-clicked.c
index c99759d..1742f2d 100644
--- a/src/anastasis/anastasis-gtk_handle-main-window-back-clicked.c
+++ b/src/anastasis/anastasis-gtk_handle-main-window-back-clicked.c
@@ -41,16 +41,16 @@ void
 anastasis_gtk_main_window_back_clicked (GObject *object,
                                         gpointer user_data)
 {
-  if (NULL != ra)
+  if (NULL != AG_ra)
   {
     /* This happens if we were long polling for payment */
-    ANASTASIS_redux_action_cancel (ra);
-    ra = NULL;
+    ANASTASIS_redux_action_cancel (AG_ra);
+    AG_ra = NULL;
   }
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
-                               "back",
-                               NULL,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "back",
+                                  NULL,
+                                  &AG_action_cb,
+                                  NULL);
 }
diff --git a/src/anastasis/anastasis-gtk_handle-main-window-forward-clicked.c 
b/src/anastasis/anastasis-gtk_handle-main-window-forward-clicked.c
index c6e36f3..9367f66 100644
--- a/src/anastasis/anastasis-gtk_handle-main-window-forward-clicked.c
+++ b/src/anastasis/anastasis-gtk_handle-main-window-forward-clicked.c
@@ -69,11 +69,11 @@ AG_forward_country_selecting (void)
   g_free (country_code);
   g_free (country_currency);
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
-                               "select_country",
-                               arguments,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "select_country",
+                                  arguments,
+                                  &AG_action_cb,
+                                  NULL);
   json_decref (arguments);
 }
 
@@ -86,11 +86,11 @@ AG_forward_user_attributes_collecting (void)
   AG_freeze ();
   args = AG_collect_attributes (false);
   GNUNET_assert (NULL != args);
-  ra = ANASTASIS_redux_action (redux_state,
-                               "enter_user_attributes",
-                               args,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "enter_user_attributes",
+                                  args,
+                                  &AG_action_cb,
+                                  NULL);
   json_decref (args);
 }
 
@@ -99,11 +99,11 @@ static void
 forward_authentications_editing (void)
 {
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
-                               "next",
-                               NULL,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "next",
+                                  NULL,
+                                  &AG_action_cb,
+                                  NULL);
 }
 
 
@@ -111,11 +111,11 @@ static void
 forward_policies_reviewing (void)
 {
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
-                               "next",
-                               NULL,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "next",
+                                  NULL,
+                                  &AG_action_cb,
+                                  NULL);
 }
 
 
@@ -134,11 +134,11 @@ forward_secret_editing (void)
                          GNUNET_JSON_from_data (str,
                                                 strlen (str)));
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
-                               "enter_secret",
-                               arguments,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "enter_secret",
+                                  arguments,
+                                  &AG_action_cb,
+                                  NULL);
   json_decref (arguments);
 }
 
diff --git a/src/anastasis/anastasis-gtk_handle-method-email.c 
b/src/anastasis/anastasis-gtk_handle-method-email.c
index 693b824..ffc3128 100644
--- a/src/anastasis/anastasis-gtk_handle-method-email.c
+++ b/src/anastasis/anastasis-gtk_handle-method-email.c
@@ -195,11 +195,11 @@ anastasis_gtk_b_email_dialog_response_cb (GtkDialog 
*dialog,
   gtk_widget_destroy (GTK_WIDGET (dialog));
   g_object_unref (G_OBJECT (builder));
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
-                               "add_authentication",
-                               args,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "add_authentication",
+                                  args,
+                                  &AG_action_cb,
+                                  NULL);
   json_decref (args);
 }
 
diff --git a/src/anastasis/anastasis-gtk_handle-method-post.c 
b/src/anastasis/anastasis-gtk_handle-method-post.c
index 50b0996..2a206be 100644
--- a/src/anastasis/anastasis-gtk_handle-method-post.c
+++ b/src/anastasis/anastasis-gtk_handle-method-post.c
@@ -108,11 +108,11 @@ anastasis_gtk_b_post_dialog_response_cb (GtkDialog 
*dialog,
   gtk_widget_destroy (GTK_WIDGET (dialog));
   g_object_unref (G_OBJECT (builder));
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
-                               "add_authentication",
-                               args,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "add_authentication",
+                                  args,
+                                  &AG_action_cb,
+                                  NULL);
   json_decref (args);
 }
 
diff --git a/src/anastasis/anastasis-gtk_handle-method-question.c 
b/src/anastasis/anastasis-gtk_handle-method-question.c
index 18d716b..c7a13cd 100644
--- a/src/anastasis/anastasis-gtk_handle-method-question.c
+++ b/src/anastasis/anastasis-gtk_handle-method-question.c
@@ -74,11 +74,11 @@ anastasis_gtk_b_question_dialog_response_cb (GtkDialog 
*dialog,
   gtk_widget_destroy (GTK_WIDGET (dialog));
   g_object_unref (G_OBJECT (builder));
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
-                               "add_authentication",
-                               args,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "add_authentication",
+                                  args,
+                                  &AG_action_cb,
+                                  NULL);
   json_decref (args);
 }
 
diff --git a/src/anastasis/anastasis-gtk_handle-method-sms.c 
b/src/anastasis/anastasis-gtk_handle-method-sms.c
index 3c203a5..75d4895 100644
--- a/src/anastasis/anastasis-gtk_handle-method-sms.c
+++ b/src/anastasis/anastasis-gtk_handle-method-sms.c
@@ -175,11 +175,11 @@ anastasis_gtk_b_sms_dialog_response_cb (GtkDialog *dialog,
   gtk_widget_destroy (GTK_WIDGET (dialog));
   g_object_unref (G_OBJECT (builder));
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
-                               "add_authentication",
-                               args,
-                               &AG_action_cb,
-                               NULL);
+  AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                  "add_authentication",
+                                  args,
+                                  &AG_action_cb,
+                                  NULL);
   json_decref (args);
 }
 
diff --git a/src/anastasis/anastasis-gtk_handle-method-video.c 
b/src/anastasis/anastasis-gtk_handle-method-video.c
index 18d716b..80b632e 100644
--- a/src/anastasis/anastasis-gtk_handle-method-video.c
+++ b/src/anastasis/anastasis-gtk_handle-method-video.c
@@ -74,7 +74,7 @@ anastasis_gtk_b_question_dialog_response_cb (GtkDialog 
*dialog,
   gtk_widget_destroy (GTK_WIDGET (dialog));
   g_object_unref (G_OBJECT (builder));
   AG_freeze ();
-  ra = ANASTASIS_redux_action (redux_state,
+  ra = ANASTASIS_redux_action (AG_AG_redux_state,
                                "add_authentication",
                                args,
                                &AG_action_cb,
diff --git a/src/anastasis/anastasis-gtk_handle-policy-version-changed.c 
b/src/anastasis/anastasis-gtk_handle-policy-version-changed.c
index a611848..d4fec7c 100644
--- a/src/anastasis/anastasis-gtk_handle-policy-version-changed.c
+++ b/src/anastasis/anastasis-gtk_handle-policy-version-changed.c
@@ -61,7 +61,7 @@ change_action_cb (void *cls,
                   json_t *response)
 {
   (void) cls;
-  ra = NULL;
+  AG_ra = NULL;
   if (TALER_EC_NONE != error_code)
   {
     AG_error ("Error: %s (%d)\n",
@@ -87,10 +87,10 @@ update_policy (void)
   gint version;
   const char *provider_url;
 
-  if (NULL != ra)
+  if (NULL != AG_ra)
   {
-    ANASTASIS_redux_action_cancel (ra);
-    ra = NULL;
+    ANASTASIS_redux_action_cancel (AG_ra);
+    AG_ra = NULL;
   }
   {
     GtkTreeStore *ts;
@@ -125,11 +125,11 @@ update_policy (void)
                       "provider_url",
                       provider_url);
     GNUNET_assert (NULL != args);
-    ra = ANASTASIS_redux_action (redux_state,
-                                 "change_version",
-                                 args,
-                                 &change_action_cb,
-                                 NULL);
+    AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                    "change_version",
+                                    args,
+                                    &change_action_cb,
+                                    NULL);
     json_decref (args);
   }
 }
diff --git a/src/anastasis/anastasis-gtk_handle-recovery-button-clicked.c 
b/src/anastasis/anastasis-gtk_handle-recovery-button-clicked.c
index e74c4da..0f7f036 100644
--- a/src/anastasis/anastasis-gtk_handle-recovery-button-clicked.c
+++ b/src/anastasis/anastasis-gtk_handle-recovery-button-clicked.c
@@ -44,7 +44,7 @@ anastasis_gtk_recovery_button_clicked (GObject *object,
   json_t *j;
 
   AG_freeze ();
-  j = ANASTASIS_recovery_start (cfg);
+  j = ANASTASIS_recovery_start (AG_cfg);
   AG_action_cb (NULL,
                 TALER_EC_NONE,
                 j);
diff --git a/src/anastasis/anastasis-gtk_handle-secret-buttons.c 
b/src/anastasis/anastasis-gtk_handle-secret-buttons.c
index 897c609..6b67d2c 100644
--- a/src/anastasis/anastasis-gtk_handle-secret-buttons.c
+++ b/src/anastasis/anastasis-gtk_handle-secret-buttons.c
@@ -121,11 +121,11 @@ open_secret_dialog_response_cb (GtkDialog *dialog,
                                                   data_size));
     GNUNET_free (data);
     AG_freeze ();
-    ra = ANASTASIS_redux_action (redux_state,
-                                 "enter_secret",
-                                 arguments,
-                                 &AG_action_cb,
-                                 NULL);
+    AG_ra = ANASTASIS_redux_action (AG_AG_redux_state,
+                                    "enter_secret",
+                                    arguments,
+                                    &AG_action_cb,
+                                    NULL);
     json_decref (arguments);
   }
 }
@@ -200,7 +200,7 @@ save_secret_dialog_response_cb (GtkDialog *dialog,
   g_object_unref (G_OBJECT (builder));
 
   GNUNET_assert (GNUNET_OK ==
-                 GNUNET_JSON_parse (redux_state,
+                 GNUNET_JSON_parse (AG_AG_redux_state,
                                     spec,
                                     NULL, NULL));
   {
@@ -287,7 +287,7 @@ anastasis_gtk_secret_copy_button_clicked_cb (GtkButton 
*button,
   GtkClipboard *cb;
 
   GNUNET_assert (GNUNET_OK ==
-                 GNUNET_JSON_parse (redux_state,
+                 GNUNET_JSON_parse (AG_AG_redux_state,
                                     spec,
                                     NULL, NULL));
   cb = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
diff --git a/src/anastasis/anastasis-gtk_helper.c 
b/src/anastasis/anastasis-gtk_helper.c
index 0c3bc34..f548c38 100644
--- a/src/anastasis/anastasis-gtk_helper.c
+++ b/src/anastasis/anastasis-gtk_helper.c
@@ -41,7 +41,7 @@ AG_thaw ()
 {
   AG_error_clear ();
   AG_sensitive ("anastasis_gtk_main_window");
-  GNUNET_assert (NULL == ra);
+  GNUNET_assert (NULL == AG_ra);
 }
 
 
@@ -49,7 +49,7 @@ void
 AG_freeze ()
 {
   AG_insensitive ("anastasis_gtk_main_window");
-  GNUNET_assert (NULL == ra);
+  GNUNET_assert (NULL == AG_ra);
 }
 
 
@@ -200,9 +200,9 @@ AG_check_state (json_t *state,
 GObject *
 GCG_get_main_window_object (const char *name)
 {
-  if (NULL == ml)
+  if (NULL == AG_ml)
     return NULL;
-  return GNUNET_GTK_main_loop_get_object (ml,
+  return GNUNET_GTK_main_loop_get_object (AG_ml,
                                           name);
 }
 
diff --git a/src/anastasis/anastasis-gtk_io.c b/src/anastasis/anastasis-gtk_io.c
index 6558918..292e1da 100644
--- a/src/anastasis/anastasis-gtk_io.c
+++ b/src/anastasis/anastasis-gtk_io.c
@@ -108,7 +108,7 @@ save_user_attributes_collecting (void)
     return;
   }
   GNUNET_break (0 ==
-                json_object_set (redux_state,
+                json_object_set (AG_AG_redux_state,
                                  "identity_attributes",
                                  json_object_get (ia,
                                                   "identity_attributes")));
@@ -129,7 +129,7 @@ save_secret_editing (void)
                        "anastasis_gtk_enter_secret_entry"));
   str = gtk_entry_get_text (entry);
   GNUNET_assert (0 ==
-                 json_object_set_new (redux_state,
+                 json_object_set_new (AG_AG_redux_state,
                                       "core_secret",
                                       GNUNET_JSON_from_data (str,
                                                              strlen (str))));
@@ -188,7 +188,7 @@ save_directory_dialog_response_cb (GtkDialog *dialog,
     }
   }
   if (0 !=
-      json_dump_file (redux_state,
+      json_dump_file (AG_AG_redux_state,
                       filename,
                       JSON_COMPACT))
   {

diff --git a/src/anastasis/anastasis-gtk.h b/src/anastasis/anastasis-gtk.h
index 80e858d..e6df970 100644
--- a/src/anastasis/anastasis-gtk.h
+++ b/src/anastasis/anastasis-gtk.h
@@ -34,12 +34,12 @@
 /**
  * Handle to our main loop.
  */
-extern struct GNUNET_GTK_MainLoop *ml;
+extern struct GNUNET_GTK_MainLoop *AG_ml;
 
 /**
  * Our configuration.
  */
-extern const struct GNUNET_CONFIGURATION_Handle *cfg;
+extern const struct GNUNET_CONFIGURATION_Handle *AG_cfg;
 
 /**
  * Hash map from UUID hashes to GtkWidgets.
@@ -49,16 +49,16 @@ extern struct GNUNET_CONTAINER_MultiHashMap 
*AG_entry_attributes;
 /**
  * Actual state.
  */
-extern json_t *redux_state;
+extern json_t *AG_AG_redux_state;
 
 /**
  * Handle to an ongoing action.
  */
-extern struct ANASTASIS_ReduxAction *ra;
+extern struct ANASTASIS_ReduxAction *AG_ra;
 
 
 /**
  * Load #redux_state from @a filename.
  *
  * @param filename to load
  */
@@ -49,16 +49,16 @@ extern struct GNUNET_CONTAINER_MultiHashMap 
 
 /**
- * Load #redux_state from @a filename.
+ * Load #AG_AG_redux_state from @a filename.
  *
  * @param filename to load
-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]